Climate-Change Christmas Carols
Description: Shouts & Murmurs by Ethan Kuperberg: “Deck the halls of our mountain hideout, / Fa la la la la, la la la la! / Hope all humans have not died out…”

#### Shouts & Murmurs December 22, 2014 Issue

# Climate-Change Christmas Carols

##

### By Ethan Kuperberg

Table of Contents
Credit Illustration by Nishant Choksi

oh, the weather outside is frightful, The heat wave brutal and spiteful. Our crops have no water to grow— Let it snow, let it snow, let it snow!

Looks like the heat wave ain’t stoppin’, Our dust-storm coughs are a-whoppin’. All fish went extinct long ago— For the love of sweet Christ, let it snow!

*

frosty the snowman, may he rest in peace, poor soul. With his melted nose and his melted mouth, And two eyes made out of coal. Frosty the Snowman, did you say his eyes were coal? Can you pass that coal? We could use some coal. Let us rob his grave for coal.

*

oh, christmas tree, oh, Christmas tree! Thy plastic branches don’t shed. Oh, Christmas tree, oh, Christmas tree! We wish real trees weren’t all dead.

*

sleigh bells ring, are you listening? In L.A., hail is glistening. In New Mexico, there is six feet of snow. The desert is a winter wonderland!

Gone away is the West Side, Here to stay is the high tide. If you want to spelunk, San Francisco has sunk. California’s now an underwater land!

In Mojave, we can build a snowman, And pretend that he is Mom or Dad. He’ll say, “Did your parents escape the horrific flash floods?,” and we’ll say, “No, man. But you can be our new dad now.”

*

i’m dreaming of an ozone layer, Just like the one I used to know, Which kept out UV rays, Before aerosol sprays, And allowed for actual snow.

*

deck the halls of our mountain hideout, Fa la la la la, la la la la! Hope all humans have not died out, Fa la la la la, la la la la! Don our hazmat suits on tight now, Fa la la, la la la, la la la! Oxygen is leaking right now, Fa la—!

*

chestnuts roasting on an open fire, Cars and houses roasting, too. Our whole city is an open pyre— Put those chestnuts away, we have to leave now.

*

i have a little dreidel, I made it out of clay. And when it’s dry and ready, Oh, dreidel, I will pray— That I can barter you for enough cans of soup to last me through the tornado.

*

silent night! Endless night! All is dark, there’s no light. Cyclone clouds have blocked out the sky, We’re almost out of our dry-meat supply. Sleep in uneasy peace. We may have to eat Aunt Bernice. ♦

Ethan Kuperberg is a ﬁlmmaker and a writer for Amazon’s series “Transparent.”

- Bio
- All work

&

##### Sign up to get the best of The New Yorker delivered to your inbox every day

##### Sign up for newsletters

E-mail address

##### Related Stories

#### Sketchbook

## Nondenominational Carols

### By Roz Chast

#### Shouts & Murmurs

## Holly or Challah?

### By Paul Rudnick

##### You Might Like

Link your
subscription
Link your subscription
Have a login?
Sign In
Already have a login? Sign in
Link Your
Subscription
Have a login?
Sign in